@@ -9,8 +9,10 @@ class EiTV1: public PIRKeysetMetaData
 {
 public:
   EiTV1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 #endif // EI_H
