@@ -148,6 +148,28 @@ public:
 };
 
 
+class SonyDVD2: public PIRKeysetMetaData
+{
+public:
+  SonyDVD2(
+    unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
+};
+
+
+class SonyDVD2a: public SonyDVD2
+{
+public:
+  SonyDVD2a(
+    unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
+};
+
+
 class SonyVCR1: public PIRKeysetMetaData
 {
 public:
@@ -222,4 +244,24 @@ public:
     QObject *guiObject);
 };
 
+class SonyProjector1: public PIRKeysetMetaData
+{
+public:
+  SonyProjector1(
+    unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
+};
+
+class SonyProjector1a: public SonyProjector1
+{
+public:
+  SonyProjector1a(
+    unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
+};
+
 #endif // SONY_H
