@@ -18,6 +18,7 @@ enum PIRMakeName{
   Bush_Make,
   Cambridge_Make,
   Canon_Make,
+  Cisco_Make,
   Compro_Make,
   Daewoo_Make,
   Dell_Make,
@@ -34,6 +35,7 @@ enum PIRMakeName{
   Epson_Make,
   Fortec_Make,
   Foxtel_Make,
+  Gadmei_Make,
   Genius_Make,
   GoldStar_Make,
   Grundig_Make,
@@ -52,6 +54,7 @@ enum PIRMakeName{
   Kenwood_Make,
   Lexuz_Make,
   LG_Make,
+  Loewe_Make,
   Logitech_Make,
   Magnavox_Make,
   Magnum_Make,
@@ -62,11 +65,14 @@ enum PIRMakeName{
   Nokia_Make,
   Octagon_Make,
   Onida_Make,
+  Onkyo_Make,
+  Orion_Make,
   Panasonic_Make,
   Philco_Make,
   Philips_Make,
   Pinnacle_Make,
   Pioneer_Make,
+  Proview_Make,
   QNAP_Make,
   Raite_Make,
   RCA_Make,
@@ -79,7 +85,10 @@ enum PIRMakeName{
   Sky_Make,
   Sony_Make,
   Starsat_Make,
+  Strong_Make,
   Technics_Make,
+  Technisat_Make,
+  Telefunken_Make,
   Telenet_Make,
   Thomson_Make,
   Tivo_Make,
