@@ -4,6 +4,7 @@
 enum PIRPanelName
 {
   Main_Panel,
+  Alt_Main_Panel,
   Utility_Panel,
   Keypad_Panel,
   Menu_Panel,
@@ -19,4 +20,13 @@ enum PIRPanelName
 };
 
 
+enum PIRTabBarName
+{
+  Universal_Tabs,
+  TV_Tabs,
+  VideoMedia_Tabs,
+  AC_Tabs,
+  Record_Tabs
+};
+
 #endif // PIRPANELNAMES_H
